<?php

namespace Drupal\redirect_delete_warning\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\ViewEvent;
use Drupal\node\Entity\Node;
use Drupal\Core\Render\Markup;

class RedirectDeleteWarningSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      KernelEvents::VIEW => ['onView', 100],
    ];
  }

  
  public function onView(ViewEvent $event) {
    $request = $event->getRequest();
  
    if (str_contains($request->getRequestUri(), '/delete')) {
      $entity = $request->attributes->get('node') ?? $request->attributes->get('taxonomy_term');
  
      if ($entity instanceof \Drupal\Core\Entity\EntityInterface) {
        $target_uri = 'internal:/' . $entity->toUrl()->getInternalPath();
  
        $connection = \Drupal::database();
        $results = $connection->select('redirect', 'r')
          ->fields('r', ['redirect_source__path'])
          ->condition('redirect_redirect__uri', $target_uri)
          ->execute()
          ->fetchCol();
  
        if (!empty($results)) {
          $message = '<div style="background-color:red;color:white;padding:1rem;font-weight:bold;margin-bottom:1rem;">
            ⚠ WARNING: This page has ' . count($results) . ' redirect(s) pointing to it!
          </div>';
  
          $response = $event->getControllerResult();
  
          if (is_array($response)) {
            $response['#prefix'] = Markup::create($message);
            $event->setControllerResult($response);
          }
        }
      }
    }
  }  
}